@@ -20,6 +20,9 @@ group_indices_se <- function(.data, groupingVars, add = FALSE) {
   if(!(is.data.frame(.data) || dplyr::is.tbl(.data))) {
     stop("seplyr::group_indices_se first argument must be a data.frame or tbl")
   }
+  if(!is.character(groupingVars)) {
+    stop("seplyr::group_indices_se groupingVars must be a character vector")
+  }
   # convert char vector into spliceable vector
   groupingSyms <- rlang::syms(groupingVars)
   dplyr::group_indices(.data = .data, !!!groupingSyms, add = add)
